pub struct ExecutionContext { /* private fields */ }Expand description
Execution context providing access to table metadata and statistics.
Implementations
Sourceimpl ExecutionContext
impl ExecutionContext
Sourcepub fn register_table(&mut self, table: impl Into<String>, stats: TableStats)
pub fn register_table(&mut self, table: impl Into<String>, stats: TableStats)
Registers table statistics.
Sourcepub fn get_stats(&self, table: &str) -> Option<&TableStats>
pub fn get_stats(&self, table: &str) -> Option<&TableStats>
Gets statistics for a table.
Sourcepub fn has_index(&self, table: &str, columns: &[&str]) -> bool
pub fn has_index(&self, table: &str, columns: &[&str]) -> bool
Checks if a table has an index on the given columns.
Sourcepub fn find_index(&self, table: &str, columns: &[&str]) -> Option<&IndexInfo>
pub fn find_index(&self, table: &str, columns: &[&str]) -> Option<&IndexInfo>
Finds an index for the given columns.
Sourcepub fn find_gin_index(&self, table: &str, column: &str) -> Option<&IndexInfo>
pub fn find_gin_index(&self, table: &str, column: &str) -> Option<&IndexInfo>
Finds a GIN index for the given column.
Sourcepub fn find_primary_index(&self, table: &str) -> Option<&IndexInfo>
pub fn find_primary_index(&self, table: &str) -> Option<&IndexInfo>
Finds the primary key index (unique BTree index) for a table. Returns the first unique BTree index found, which is typically the primary key.