NestedLoopJoin

Struct NestedLoopJoin 

pub struct NestedLoopJoin { /* private fields */ }
Nested Loop Join executor.

The simplest join algorithm that compares every pair of rows. Best for small relations or non-equi joins.

Implementations

Source

impl NestedLoopJoin

pub fn new( left_key_index: usize, right_key_index: usize, is_outer_join: bool, ) -> Self

Creates a new nested loop join executor.

pub fn inner(left_key_index: usize, right_key_index: usize) -> Self

Creates an inner nested loop join.

pub fn left_outer(left_key_index: usize, right_key_index: usize) -> Self

Creates a left outer nested loop join.

pub fn execute(&self, left: Relation, right: Relation) -> Relation

Executes the nested loop join with equality comparison.

pub fn execute_with_predicate<F>( &self, left: Relation, right: Relation, predicate: F, ) -> Relation
where F: Fn(&Value, &Value) -> bool,

Executes the nested loop join with a custom predicate.