pub struct LimitExecutor { /* private fields */ }Expand description
Limit executor - applies LIMIT and OFFSET to a relation.
Implementations
Sourceimpl LimitExecutor
impl LimitExecutor
Sourcepub fn limit_only(limit: usize) -> Self
pub fn limit_only(limit: usize) -> Self
Creates a limit executor with only a limit (no offset).
Sourcepub fn execute(&self, input: Relation) -> Relation
pub fn execute(&self, input: Relation) -> Relation
Executes the limit on the input relation.
Note: This operation is O(offset + limit) for the actual work, but dropping the unused entries is O(n - offset - limit). In a real query engine, limit would be pushed down to avoid materializing unnecessary rows.