pub struct PhysicalPlanRunner<'a, D: DataSource> { /* private fields */ }Expand description
Physical plan runner - executes physical query plans.
The runner recursively evaluates plan nodes, executing each operator and combining results according to the plan structure.
Implementations
Sourceimpl<'a, D: DataSource> PhysicalPlanRunner<'a, D>
impl<'a, D: DataSource> PhysicalPlanRunner<'a, D>
Sourcepub fn new(data_source: &'a D) -> Self
pub fn new(data_source: &'a D) -> Self
Creates a new physical plan runner with the given data source.
Sourcepub fn execute(&self, plan: &PhysicalPlan) -> ExecutionResult<Relation>
pub fn execute(&self, plan: &PhysicalPlan) -> ExecutionResult<Relation>
Executes a physical plan and returns the result relation.