pub struct IndexJoinPass<'a> { /* private fields */ }Expand description
Pass that converts eligible joins to index nested loop joins.
Implementations
Sourceimpl<'a> IndexJoinPass<'a>
impl<'a> IndexJoinPass<'a>
Sourcepub fn new(ctx: &'a ExecutionContext) -> Self
pub fn new(ctx: &'a ExecutionContext) -> Self
Creates a new IndexJoinPass with the given execution context.
Sourcepub fn optimize(&self, plan: PhysicalPlan) -> PhysicalPlan
pub fn optimize(&self, plan: PhysicalPlan) -> PhysicalPlan
Optimizes the physical plan by converting eligible joins to index joins.