IndexSelection

Struct IndexSelection 

pub struct IndexSelection { /* private fields */ }
Index selection optimization.

Analyzes predicates and selects appropriate indexes for scans. This pass identifies Filter(Scan) patterns where the filter predicate can be satisfied using an index, converting them to IndexScan operations.

Supports:

  • Point lookups: col = value → IndexGet
  • Range scans: col > value, col < value, etc. → IndexScan
  • IN queries: col IN (v1, v2, v3) → IndexInGet
  • JSONB queries with GIN indexes → GinIndexScan

Implementations

Source

impl IndexSelection

pub fn new() -> Self

Creates a new index selection pass without context.

pub fn with_context(context: ExecutionContext) -> Self

Creates a new index selection pass with execution context.

Source

impl IndexSelection

pub fn extract_predicates(&self, predicate: &Expr) -> Vec<PredicateInfo>

Extracts all simple predicates from a compound predicate.